Appendix: Glossary
==================

Definitions of LedgerLoom terms: journal, ledger, posting, account, contra account, accrual, and more.

**Status:** Planned (living doc).


# docs/source/ledgerloom_appendix_faq.rst

Appendix: FAQ
=============

Frequently asked questions about LedgerLoom concepts and usage.

**Status:** Planned (living doc).